==> hinemos_agent-4.0.2_rhel4_32.tar.gz: com/clustercontrol/ws/agent/JobInfoNotFound.java <==

package com.clustercontrol.ws.agent;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for JobInfoNotFound complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="JobInfoNotFound">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endStatus" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="facilityId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="jobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="jobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="message" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="noticeType" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="paramId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="parentJobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="parentJobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="sessionId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="status" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="targetJobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="targetJobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JobInfoNotFound", propOrder = {
    "endStatus",
    "facilityId",
    "jobId",
    "jobunitId",
    "message",
    "noticeType",
    "paramId",
    "parentJobId",
    "parentJobunitId",
    "sessionId",
    "status",
    "targetJobId",
    "targetJobunitId"
})
public class JobInfoNotFound {

    protected int endStatus;
    protected String facilityId;
    protected String jobId;
    protected String jobunitId;
    protected String message;
    protected int noticeType;
    protected String paramId;
    protected String parentJobId;
    protected String parentJobunitId;
    protected String sessionId;
    protected int status;
    protected String targetJobId;
    protected String targetJobunitId;

    /**
     * Gets the value of the endStatus property.
     * 
     */
    public int getEndStatus() {
        return endStatus;
    }

    /**
     * Sets the value of the endStatus property.
     * 
     */
    public void setEndStatus(int value) {
        this.endStatus = value;
    }

    /**
     * Gets the value of the facilityId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityId() {
        return facilityId;
    }

    /**
     * Sets the value of the facilityId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityId(String value) {
        this.facilityId = value;
    }

    /**
     * Gets the value of the jobId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJobId() {
        return jobId;
    }

    /**
     * Sets the value of the jobId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJobId(String value) {
        this.jobId = value;
    }

    /**
     * Gets the value of the jobunitId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJobunitId() {
        return jobunitId;
    }

    /**
     * Sets the value of the jobunitId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJobunitId(String value) {
        this.jobunitId = value;
    }

    /**
     * Gets the value of the message property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessage() {
        return message;
    }

    /**
     * Sets the value of the message property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessage(String value) {
        this.message = value;
    }

    /**
     * Gets the value of the noticeType property.
     * 
     */
    public int getNoticeType() {
        return noticeType;
    }

    /**
     * Sets the value of the noticeType property.
     * 
     */
    public void setNoticeType(int value) {
        this.noticeType = value;
    }

    /**
     * Gets the value of the paramId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParamId() {
        return paramId;
    }

    /**
     * Sets the value of the paramId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParamId(String value) {
        this.paramId = value;
    }

    /**
     * Gets the value of the parentJobId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParentJobId() {
        return parentJobId;
    }

    /**
     * Sets the value of the parentJobId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParentJobId(String value) {
        this.parentJobId = value;
    }

    /**
     * Gets the value of the parentJobunitId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParentJobunitId() {
        return parentJobunitId;
    }

    /**
     * Sets the value of the parentJobunitId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParentJobunitId(String value) {
        this.parentJobunitId = value;
    }

    /**
     * Gets the value of the sessionId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSessionId() {
        return sessionId;
    }

    /**
     * Sets the value of the sessionId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSessionId(String value) {
        this.sessionId = value;
    }

    /**
     * Gets the value of the status property.
     * 
     */
    public int getStatus() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     */
    public void setStatus(int value) {
        this.status = value;
    }

    /**
     * Gets the value of the targetJobId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetJobId() {
        return targetJobId;
    }

    /**
     * Sets the value of the targetJobId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetJobId(String value) {
        this.targetJobId = value;
    }

    /**
     * Gets the value of the targetJobunitId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetJobunitId() {
        return targetJobunitId;
    }

    /**
     * Sets the value of the targetJobunitId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetJobunitId(String value) {
        this.targetJobunitId = value;
    }

}

==> hinemos_agent-4.1.4_rhel4_64.tar.gz: com/clustercontrol/ws/agent/JobInfoNotFound.java <==

package com.clustercontrol.ws.agent;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>JobInfoNotFound complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="JobInfoNotFound">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endStatus" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="facilityId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="jobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="jobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="message" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="noticeType" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="paramId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="parentJobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="parentJobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="sessionId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="status" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element name="targetJobId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="targetJobunitId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "JobInfoNotFound", propOrder = {
    "endStatus",
    "facilityId",
    "jobId",
    "jobunitId",
    "message",
    "noticeType",
    "paramId",
    "parentJobId",
    "parentJobunitId",
    "sessionId",
    "status",
    "targetJobId",
    "targetJobunitId"
})
public class JobInfoNotFound {

    protected int endStatus;
    protected String facilityId;
    protected String jobId;
    protected String jobunitId;
    protected String message;
    protected int noticeType;
    protected String paramId;
    protected String parentJobId;
    protected String parentJobunitId;
    protected String sessionId;
    protected int status;
    protected String targetJobId;
    protected String targetJobunitId;

    /**
     * endStatusプロパティの値を取得します。
     * 
     */
    public int getEndStatus() {
        return endStatus;
    }

    /**
     * endStatusプロパティの値を設定します。
     * 
     */
    public void setEndStatus(int value) {
        this.endStatus = value;
    }

    /**
     * facilityIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFacilityId() {
        return facilityId;
    }

    /**
     * facilityIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFacilityId(String value) {
        this.facilityId = value;
    }

    /**
     * jobIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJobId() {
        return jobId;
    }

    /**
     * jobIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJobId(String value) {
        this.jobId = value;
    }

    /**
     * jobunitIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJobunitId() {
        return jobunitId;
    }

    /**
     * jobunitIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJobunitId(String value) {
        this.jobunitId = value;
    }

    /**
     * messageプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessage() {
        return message;
    }

    /**
     * messageプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessage(String value) {
        this.message = value;
    }

    /**
     * noticeTypeプロパティの値を取得します。
     * 
     */
    public int getNoticeType() {
        return noticeType;
    }

    /**
     * noticeTypeプロパティの値を設定します。
     * 
     */
    public void setNoticeType(int value) {
        this.noticeType = value;
    }

    /**
     * paramIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParamId() {
        return paramId;
    }

    /**
     * paramIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParamId(String value) {
        this.paramId = value;
    }

    /**
     * parentJobIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParentJobId() {
        return parentJobId;
    }

    /**
     * parentJobIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParentJobId(String value) {
        this.parentJobId = value;
    }

    /**
     * parentJobunitIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getParentJobunitId() {
        return parentJobunitId;
    }

    /**
     * parentJobunitIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setParentJobunitId(String value) {
        this.parentJobunitId = value;
    }

    /**
     * sessionIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSessionId() {
        return sessionId;
    }

    /**
     * sessionIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSessionId(String value) {
        this.sessionId = value;
    }

    /**
     * statusプロパティの値を取得します。
     * 
     */
    public int getStatus() {
        return status;
    }

    /**
     * statusプロパティの値を設定します。
     * 
     */
    public void setStatus(int value) {
        this.status = value;
    }

    /**
     * targetJobIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetJobId() {
        return targetJobId;
    }

    /**
     * targetJobIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetJobId(String value) {
        this.targetJobId = value;
    }

    /**
     * targetJobunitIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetJobunitId() {
        return targetJobunitId;
    }

    /**
     * targetJobunitIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetJobunitId(String value) {
        this.targetJobunitId = value;
    }

}
